@@ -2,7 +2,7 @@
  * \file Geodesic.hpp
  * \brief Header for GeographicLib::Geodesic class
  *
- * Copyright (c) Charles Karney (2009-2022) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2023) <karney@alum.mit.edu> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -11,6 +11,7 @@
 #define GEOGRAPHICLIB_GEODESIC_HPP 1
 
 #include <GeographicLib/Constants.hpp>
+#include <GeographicLib/GeodesicExact.hpp>
 
 #if !defined(GEOGRAPHICLIB_GEODESIC_ORDER)
 /**
@@ -133,7 +134,8 @@ namespace GeographicLib {
    * The calculations are accurate to better than 15 nm (15 nanometers) for the
    * WGS84 ellipsoid.  See Sec. 9 of
    * <a href="https://arxiv.org/abs/1102.1215v1">arXiv:1102.1215v1</a> for
-   * details.  The algorithms used by this class are based on series expansions
+   * details.  With \e exact = false (the default) in the constructor,
+   * the algorithms used by this class are based on series expansions
    * using the flattening \e f as a small parameter.  These are only accurate
    * for |<i>f</i>| &lt; 0.02; however reasonably accurate results will be
    * obtained for |<i>f</i>| &lt; 0.2.  Here is a table of the approximate
@@ -147,7 +149,8 @@ namespace GeographicLib {
    *     0.1     1.5 mm
    *     0.2     300 mm
    * </pre>
-   * For very eccentric ellipsoids, use GeodesicExact instead.
+   * For very eccentric ellipsoids, set \e exact to true in the constructor;
+   * this will delegate the calculations to the GeodesicExact class.
    *
    * The algorithms are described in
    * - C. F. F. Karney,
@@ -208,8 +211,11 @@ namespace GeographicLib {
                              real sinx, real cosx, const real c[], int n);
     static real Astroid(real x, real y);
 
-    real _a, _f, _f1, _e2, _ep2, _n, _b, _c2, _etol2;
+    real _a, _f;
+    bool _exact;
+    real _f1, _e2, _ep2, _n, _b, _c2, _etol2;
     real _aA3x[nA3x_], _cC3x[nC3x_], _cC4x[nC4x_];
+    GeodesicExact _geodexact;
 
     void Lengths(real eps, real sig12,
                  real ssig1, real csig1, real dn1,
@@ -249,7 +255,6 @@ namespace GeographicLib {
     void C3f(real eps, real c[]) const;
     void C4coeff();
     void C4f(real k2, real c[]) const;
-
   public:
 
     /**
@@ -338,10 +343,16 @@ namespace GeographicLib {
      * @param[in] a equatorial radius (meters).
      * @param[in] f flattening of ellipsoid.  Setting \e f = 0 gives a sphere.
      *   Negative \e f gives a prolate ellipsoid.
+     * @param[in] exact if true use exact formulation in terms of elliptic
+     *   integrals instead of series expansions (default false).
      * @exception GeographicErr if \e a or (1 &minus; \e f) \e a is not
      *   positive.
+     *
+     * With \e exact = true, this class delegates the calculations to the
+     * GeodesicExact and GeodesicLineExact classes which solve the geodesic
+     * problems in terms of elliptic integrals.
      **********************************************************************/
-    Geodesic(real a, real f);
+    Geodesic(real a, real f, bool exact = false);
     ///@}
 
     /** \name Direct geodesic problem specified in terms of distance.
@@ -804,6 +815,11 @@ namespace GeographicLib {
      **********************************************************************/
     ///@{
 
+    /**
+     * Typedef for the class for computing multiple points on a geodesic.
+     **********************************************************************/
+    typedef GeodesicLine LineClass;
+
     /**
      * Set up to compute several points on a single geodesic.
      *
@@ -954,6 +970,12 @@ namespace GeographicLib {
      **********************************************************************/
     Math::real Flattening() const { return _f; }
 
+    /**
+     * @return \e exact whether the exact formulation is used.  This is the
+     *   value used in the constructor.
+     **********************************************************************/
+    bool Exact() const { return _exact; }
+
     /**
      * @return total area of ellipsoid in meters<sup>2</sup>.  The area of a
      *   polygon encircling a pole can be found by adding
