@@ -2,7 +2,7 @@
  * \file MGRS.hpp
  * \brief Header for GeographicLib::MGRS class
  *
- * Copyright (c) Charles Karney (2008-2022) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2023) <karney@alum.mit.edu> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -88,15 +88,7 @@ namespace GeographicLib {
     static const int maxeasting_[4];
     static const int minnorthing_[4];
     static const int maxnorthing_[4];
-#if GEOGRAPHICLIB_PRECISION == 4
-    // Work around an enum lossage introduced in boost 1.76
-    //   https://github.com/boostorg/multiprecision/issues/324
-    // and fixed in
-    //   https://github.com/boostorg/multiprecision/pull/333
-    static const int
-#else
     enum {
-#endif
       base_ = 10,
       // Top-level tiles are 10^5 m = 100 km on a side
       tilelevel_ = 5,
@@ -108,11 +100,7 @@ namespace GeographicLib {
       maxprec_ = 5 + 6,
       // For generating digits at maxprec
       mult_ = 1000000
-#if GEOGRAPHICLIB_PRECISION == 4
-      ;
-#else
     };
-#endif
     static void CheckCoords(bool utmp, bool& northp, real& x, real& y);
     static int UTMRow(int iband, int icol, int irow);
 
@@ -150,15 +138,7 @@ namespace GeographicLib {
       return y >= 0 ? b : -(b + 1);
     }
     // UTMUPS accesses these enums
-#if GEOGRAPHICLIB_PRECISION == 4
-    // Work around an enum lossage introduced in boost 1.76
-    //   https://github.com/boostorg/multiprecision/issues/324
-    // and fixed in
-    //   https://github.com/boostorg/multiprecision/pull/333
-    static const int
-#else
     enum {
-#endif
       tile_ = 100000,            // Size MGRS blocks
       minutmcol_ = 1,
       maxutmcol_ = 9,
@@ -174,11 +154,7 @@ namespace GeographicLib {
       utmeasting_ = 5,           // UTM false easting
       // Difference between S hemisphere northing and N hemisphere northing
       utmNshift_ = (maxutmSrow_ - minutmNrow_) * tile_
-#if GEOGRAPHICLIB_PRECISION == 4
-      ;
-#else
     };
-#endif
     MGRS() = delete;            // Disable constructor
 
   public:
