@@ -2,7 +2,7 @@
  * \file Rhumb.hpp
  * \brief Header for GeographicLib::Rhumb and GeographicLib::RhumbLine classes
  *
- * Copyright (c) Charles Karney (2014-2022) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2014-2023) <karney@alum.mit.edu> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -11,22 +11,28 @@
 #define GEOGRAPHICLIB_RHUMB_HPP 1
 
 #include <GeographicLib/Constants.hpp>
-#include <GeographicLib/Ellipsoid.hpp>
+#include <GeographicLib/DAuxLatitude.hpp>
+#include <vector>
 
 #if !defined(GEOGRAPHICLIB_RHUMBAREA_ORDER)
 /**
  * The order of the series approximation used in rhumb area calculations.
- * GEOGRAPHICLIB_RHUMBAREA_ORDER can be set to any integer in [4, 8].
+ * GEOGRAPHICLIB_RHUMBAREA_ORDER can be set to one of [4, 5, 6, 7, 8].
  **********************************************************************/
 #  define GEOGRAPHICLIB_RHUMBAREA_ORDER \
   (GEOGRAPHICLIB_PRECISION == 2 ? 6 : \
    (GEOGRAPHICLIB_PRECISION == 1 ? 4 : 8))
 #endif
 
+#if defined(_MSC_VER)
+// Squelch warnings about dll vs vector
+#  pragma warning (push)
+#  pragma warning (disable: 4251)
+#endif
+
 namespace GeographicLib {
 
   class RhumbLine;
-  template<class T> class PolygonAreaT;
 
   /**
    * \brief Solve of the direct and inverse rhumb problems.
@@ -57,6 +63,13 @@ namespace GeographicLib {
    * and Tokyo Narita via the rhumb line is 11400 km which is 18% longer than
    * the geodesic distance 9600 km.
    *
+   * This implementation is described in
+   * - C. F. F. Karney,<br>
+   *   <a href="https://arxiv.org/abs/2303.03219">The area of rhumb
+   *   polygons</a>,<br>
+   *   Technical Report, SRI International, March 2023.<br>
+   *   <a href="https://arxiv.org/abs/2303.03219">arxiv:2303.03219</a>
+   * .
    * For more information on rhumb lines see \ref rhumb.
    *
    * Example of use:
@@ -68,117 +81,21 @@ namespace GeographicLib {
     typedef Math::real real;
     friend class RhumbLine;
     template<class T> friend class PolygonAreaT;
-    Ellipsoid _ell;
+    DAuxLatitude _aux;
     bool _exact;
-    real _c2;
-    static const int tm_maxord = GEOGRAPHICLIB_TRANSVERSEMERCATOR_ORDER;
-    static const int maxpow_ = GEOGRAPHICLIB_RHUMBAREA_ORDER;
-    // _rR[0] unused
-    real _rR[maxpow_ + 1];
-    static real gd(real x)
-    { using std::atan; using std::sinh; return atan(sinh(x)); }
+    real _a, _f, _n, _rm, _c2;
+    int _lL;             // N.B. names of the form _[A-Z].* are reserved in C++
+    std::vector<real> _pP;      // The Fourier coefficients P_l
+    static const int Lmax_ = GEOGRAPHICLIB_RHUMBAREA_ORDER;
+    void AreaCoeffs();
+    class qIntegrand {
+      const AuxLatitude& _aux;
+    public:
+      qIntegrand(const AuxLatitude& aux);
+      real operator()(real chi) const;
+    };
 
-    // Use divided differences to determine (mu2 - mu1) / (psi2 - psi1)
-    // accurately
-    //
-    // Definition: Df(x,y,d) = (f(x) - f(y)) / (x - y)
-    // See:
-    //   W. M. Kahan and R. J. Fateman,
-    //   Symbolic computation of divided differences,
-    //   SIGSAM Bull. 33(2), 7-28 (1999)
-    //   https://doi.org/10.1145/334714.334716
-    //   http://www.cs.berkeley.edu/~fateman/papers/divdiff.pdf
-
-    static real Dlog(real x, real y) {
-      using std::sqrt; using std::asinh;
-      real t = x - y;
-      // Change
-      //
-      //   atanh(t / (x + y))
-      //
-      // to
-      //
-      //   asinh(t / (2 * sqrt(x*y)))
-      //
-      // to avoid taking atanh(1) when x is large and y is 1.  N.B., this
-      // routine is invoked with positive x and y, so no need to guard against
-      // taking the sqrt of a negative quantity.  This fixes bogus results for
-      // the area being returning when an endpoint is at a pole.
-      return t != 0 ? 2 * asinh(t / (2 * sqrt(x*y))) / t : 1 / x;
-    }
-    // N.B., x and y are in degrees
-    static real Dtan(real x, real y) {
-      real d = x - y, tx = Math::tand(x), ty = Math::tand(y), txy = tx * ty;
-      return d != 0 ?
-        (2 * txy > -1 ? (1 + txy) * Math::tand(d) : tx - ty) /
-        (d * Math::degree()) :
-        1 + txy;
-    }
-    static real Datan(real x, real y) {
-      using std::atan;
-      real d = x - y, xy = x * y;
-      return d != 0 ?
-        (2 * xy > -1 ? atan( d / (1 + xy) ) : atan(x) - atan(y)) / d :
-        1 / (1 + xy);
-    }
-    static real Dsin(real x, real y) {
-      using std::sin; using std::cos;
-      real d = (x - y) / 2;
-      return cos((x + y)/2) * (d != 0 ? sin(d) / d : 1);
-    }
-    static real Dsinh(real x, real y) {
-      using std::sinh; using std::cosh;
-      real d = (x - y) / 2;
-      return cosh((x + y) / 2) * (d != 0 ? sinh(d) / d : 1);
-    }
-    static real Dcosh(real x, real y) {
-      using std::sinh;
-      real d = (x - y) / 2;
-      return sinh((x + y) / 2) * (d != 0 ? sinh(d) / d : 1);
-    }
-    static real Dasinh(real x, real y) {
-      using std::asinh; using std::hypot;
-      real d = x - y,
-        hx = hypot(real(1), x), hy = hypot(real(1), y);
-      return d != 0 ?
-        asinh(x*y > 0 ? d * (x + y) / (x*hy + y*hx) : x*hy - y*hx) / d :
-        1 / hx;
-    }
-    static real Dgd(real x, real y) {
-      using std::sinh;
-      return Datan(sinh(x), sinh(y)) * Dsinh(x, y);
-    }
-    // N.B., x and y are the tangents of the angles
-    static real Dgdinv(real x, real y)
-    { return Dasinh(x, y) / Datan(x, y); }
-    // Copied from LambertConformalConic...
-    // Deatanhe(x,y) = eatanhe((x-y)/(1-e^2*x*y))/(x-y)
-    real Deatanhe(real x, real y) const {
-      real t = x - y, d = 1 - _ell._e2 * x * y;
-      return t != 0 ? Math::eatanhe(t / d, _ell._es) / t : _ell._e2 / d;
-    }
-    // (E(x) - E(y)) / (x - y) -- E = incomplete elliptic integral of 2nd kind
-    real DE(real x, real y) const;
-    // (mux - muy) / (phix - phiy) using elliptic integrals
-    real DRectifying(real latx, real laty) const;
-    // (psix - psiy) / (phix - phiy)
-    real DIsometric(real latx, real laty) const;
-
-    // (sum(c[j]*sin(2*j*x),j=1..n) - sum(c[j]*sin(2*j*x),j=1..n)) / (x - y)
-    static real SinCosSeries(bool sinp,
-                             real x, real y, const real c[], int n);
-    // (mux - muy) / (chix - chiy) using Krueger's series
-    real DConformalToRectifying(real chix, real chiy) const;
-    // (chix - chiy) / (mux - muy) using Krueger's series
-    real DRectifyingToConformal(real mux, real muy) const;
-
-    // (mux - muy) / (psix - psiy)
-    // N.B., psix and psiy are in degrees
-    real DIsometricToRectifying(real psix, real psiy) const;
-    // (psix - psiy) / (mux - muy)
-    real DRectifyingToIsometric(real mux, real muy) const;
-
-    real MeanSinXi(real psi1, real psi2) const;
+    real MeanSinXi(const AuxAngle& chix, const AuxAngle& chiy) const;
 
     // The following two functions (with lots of ignored arguments) mimic the
     // interface to the corresponding Geodesic function.  These are needed by
@@ -194,8 +111,8 @@ namespace GeographicLib {
                     real&, real& , real& , real& , real& S12) const {
       GenInverse(lat1, lon1, lat2, lon2, outmask, s12, azi12, S12);
     }
-  public:
 
+  public:
     /**
      * Bit masks for what calculations to do.  They specify which results to
      * return in the general routines Rhumb::GenDirect and Rhumb::GenInverse
@@ -250,15 +167,13 @@ namespace GeographicLib {
      * @param[in] a equatorial radius (meters).
      * @param[in] f flattening of ellipsoid.  Setting \e f = 0 gives a sphere.
      *   Negative \e f gives a prolate ellipsoid.
-     * @param[in] exact if true (the default) use an addition theorem for
-     *   elliptic integrals to compute divided differences; otherwise use
-     *   series expansion (accurate for |<i>f</i>| < 0.01).
+     * @param[in] exact if true use the exact expressions for the auxiliary
+     *   latitudes; otherwise use series expansion (accurate for |<i>f</i>| <
+     *   0.01) [default false].
      * @exception GeographicErr if \e a or (1 &minus; \e f) \e a is not
      *   positive.
-     *
-     * See \ref rhumb, for a detailed description of the \e exact parameter.
      **********************************************************************/
-    Rhumb(real a, real f, bool exact = true);
+    Rhumb(real a, real f, bool exact = false);
 
     /**
      * Solve the direct rhumb problem returning also the area.
@@ -388,6 +303,11 @@ namespace GeographicLib {
                     unsigned outmask,
                     real& s12, real& azi12, real& S12) const;
 
+    /**
+     * Typedef for the class for computing multiple points on a rhumb line.
+     **********************************************************************/
+    typedef RhumbLine LineClass;
+
     /**
      * Set up to compute several points on a single rhumb line.
      *
@@ -413,13 +333,13 @@ namespace GeographicLib {
      * @return \e a the equatorial radius of the ellipsoid (meters).  This is
      *   the value used in the constructor.
      **********************************************************************/
-    Math::real EquatorialRadius() const { return _ell.EquatorialRadius(); }
+    Math::real EquatorialRadius() const { return _a; }
 
     /**
      * @return \e f the  flattening of the ellipsoid.  This is the
      *   value used in the constructor.
      **********************************************************************/
-    Math::real Flattening() const { return _ell.Flattening(); }
+    Math::real Flattening() const { return _f; }
 
     /**
      * @return total area of ellipsoid in meters<sup>2</sup>.  The area of a
@@ -427,7 +347,10 @@ namespace GeographicLib {
      *   Geodesic::EllipsoidArea()/2 to the sum of \e S12 for each side of the
      *   polygon.
      **********************************************************************/
-    Math::real EllipsoidArea() const { return _ell.Area(); }
+    Math::real EllipsoidArea() const {
+      // _c2 contains a Math::degrees() factor, so 4*pi -> 2*Math::td.
+      return 2 * real(Math::td) * _c2;
+    }
     ///@}
 
     /**
@@ -460,11 +383,14 @@ namespace GeographicLib {
     typedef Math::real real;
     friend class Rhumb;
     const Rhumb& _rh;
-    real _lat1, _lon1, _azi12, _salp, _calp, _mu1, _psi1, _r1;
+    real _lat1, _lon1, _azi12, _salp, _calp, _mu1, _psi1;
+    AuxAngle _phi1, _chi1;
     // copy assignment not allowed
     RhumbLine& operator=(const RhumbLine&) = delete;
     RhumbLine(const Rhumb& rh, real lat1, real lon1, real azi12);
+
   public:
+
     /**
      * Construction is via default copy constructor.
      **********************************************************************/
@@ -515,6 +441,11 @@ namespace GeographicLib {
       ALL           = Rhumb::ALL,
     };
 
+    /**
+     * Typedef for the base class implementing rhumb lines.
+     **********************************************************************/
+    typedef Rhumb BaseClass;
+
     /**
      * Compute the position of point 2 which is a distance \e s12 (meters) from
      * point 1.  The area is also computed.
